pub struct SurveyMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on survey resources.
It is not used directly, but through the Surveys hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_surveys2 as surveys2;
use surveys2::{Surveys, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Surveys::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `insert(...)`, `list(...)`, `start(...)`, `stop(...)` and `update(...)`
// to build up your call.
let rb = hub.surveys();Implementations
Sourceimpl<'a, C> SurveyMethods<'a, C>
impl<'a, C> SurveyMethods<'a, C>
Sourcepub fn delete(&self, survey_url_id: &str) -> SurveyDeleteCall<'a, C>
pub fn delete(&self, survey_url_id: &str) -> SurveyDeleteCall<'a, C>
Create a builder to help you perform the following task:
Removes a survey from view in all user GET requests.
Arguments
surveyUrlId- External URL ID for the survey.
Sourcepub fn get(&self, survey_url_id: &str) -> SurveyGetCall<'a, C>
pub fn get(&self, survey_url_id: &str) -> SurveyGetCall<'a, C>
Create a builder to help you perform the following task:
Retrieves information about the specified survey.
Arguments
surveyUrlId- External URL ID for the survey.
Sourcepub fn insert(&self, request: Survey) -> SurveyInsertCall<'a, C>
pub fn insert(&self, request: Survey) -> SurveyInsertCall<'a, C>
Create a builder to help you perform the following task:
Creates a survey.
Arguments
request- No description provided.
Sourcepub fn list(&self) -> SurveyListCall<'a, C>
pub fn list(&self) -> SurveyListCall<'a, C>
Create a builder to help you perform the following task:
Lists the surveys owned by the authenticated user.
Sourcepub fn start(
&self,
request: SurveysStartRequest,
resource_id: &str,
) -> SurveyStartCall<'a, C>
pub fn start( &self, request: SurveysStartRequest, resource_id: &str, ) -> SurveyStartCall<'a, C>
Create a builder to help you perform the following task:
Begins running a survey.
Arguments
request- No description provided.resourceId- No description provided.
Sourcepub fn stop(&self, resource_id: &str) -> SurveyStopCall<'a, C>
pub fn stop(&self, resource_id: &str) -> SurveyStopCall<'a, C>
Create a builder to help you perform the following task:
Stops a running survey.
Arguments
resourceId- No description provided.
Sourcepub fn update(
&self,
request: Survey,
survey_url_id: &str,
) -> SurveyUpdateCall<'a, C>
pub fn update( &self, request: Survey, survey_url_id: &str, ) -> SurveyUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates a survey. Currently the only property that can be updated is the owners property.
Arguments
request- No description provided.surveyUrlId- External URL ID for the survey.